NETBOX_DEVICES_API_CALL = "/api/dcim/devices/?format=json"
NETBOX_DEVICES_API_RESPONSE = {
    "count": 37,
    "next": None,
    "previous": None,
    "results": [
        {
            "id": 1,
            "url": "http://localhost:55891/api/dcim/devices/1/?format=json",
            "display": "dmi01-akron-rtr01",
            "name": "dmi01-akron-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/sites/2/?format=json",
                "display": "DM-Akron",
                "name": "DM-Akron",
                "slug": "dm-akron",
            },
            "location": None,
            "rack": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/racks/1/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:26:44.813000Z",
        },
        {
            "id": 14,
            "url": "http://localhost:55891/api/dcim/devices/14/?format=json",
            "display": "dmi01-akron-sw01",
            "name": "dmi01-akron-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/sites/2/?format=json",
                "display": "DM-Akron",
                "name": "DM-Akron",
                "slug": "dm-akron",
            },
            "location": None,
            "rack": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/racks/1/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:11.625000Z",
        },
        {
            "id": 2,
            "url": "http://localhost:55891/api/dcim/devices/2/?format=json",
            "display": "dmi01-albany-rtr01",
            "name": "dmi01-albany-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/sites/3/?format=json",
                "display": "DM-Albany",
                "name": "DM-Albany",
                "slug": "dm-albany",
            },
            "location": None,
            "rack": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/racks/2/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 182,
                "url": "http://localhost:55891/api/ipam/ip-addresses/182/?format=json",
                "display": "2.2.2.2/10",
                "family": 4,
                "address": "2.2.2.2/10",
            },
            "primary_ip4": {
                "id": 182,
                "url": "http://localhost:55891/api/ipam/ip-addresses/182/?format=json",
                "display": "2.2.2.2/10",
                "family": 4,
                "address": "2.2.2.2/10",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:26:58.061000Z",
        },
        {
            "id": 15,
            "url": "http://localhost:55891/api/dcim/devices/15/?format=json",
            "display": "dmi01-albany-sw01",
            "name": "dmi01-albany-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/sites/3/?format=json",
                "display": "DM-Albany",
                "name": "DM-Albany",
                "slug": "dm-albany",
            },
            "location": None,
            "rack": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/racks/2/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:11.714000Z",
        },
        {
            "id": 3,
            "url": "http://localhost:55891/api/dcim/devices/3/?format=json",
            "display": "dmi01-binghamton-rtr01",
            "name": "dmi01-binghamton-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/sites/4/?format=json",
                "display": "DM-Binghamton",
                "name": "DM-Binghamton",
                "slug": "dm-binghamton",
            },
            "location": None,
            "rack": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/racks/3/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 183,
                "url": "http://localhost:55891/api/ipam/ip-addresses/183/?format=json",
                "display": "3.3.3.3/10",
                "family": 4,
                "address": "3.3.3.3/10",
            },
            "primary_ip4": {
                "id": 183,
                "url": "http://localhost:55891/api/ipam/ip-addresses/183/?format=json",
                "display": "3.3.3.3/10",
                "family": 4,
                "address": "3.3.3.3/10",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:27:13.871000Z",
        },
        {
            "id": 16,
            "url": "http://localhost:55891/api/dcim/devices/16/?format=json",
            "display": "dmi01-binghamton-sw01",
            "name": "dmi01-binghamton-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/sites/4/?format=json",
                "display": "DM-Binghamton",
                "name": "DM-Binghamton",
                "slug": "dm-binghamton",
            },
            "location": None,
            "rack": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/racks/3/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:11.799000Z",
        },
        {
            "id": 4,
            "url": "http://localhost:55891/api/dcim/devices/4/?format=json",
            "display": "dmi01-buffalo-rtr01",
            "name": "dmi01-buffalo-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/sites/5/?format=json",
                "display": "DM-Buffalo",
                "name": "DM-Buffalo",
                "slug": "dm-buffalo",
            },
            "location": None,
            "rack": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/racks/4/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 184,
                "url": "http://localhost:55891/api/ipam/ip-addresses/184/?format=json",
                "display": "4.4.4.4/10",
                "family": 4,
                "address": "4.4.4.4/10",
            },
            "primary_ip4": {
                "id": 184,
                "url": "http://localhost:55891/api/ipam/ip-addresses/184/?format=json",
                "display": "4.4.4.4/10",
                "family": 4,
                "address": "4.4.4.4/10",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:27:25.345000Z",
        },
        {
            "id": 17,
            "url": "http://localhost:55891/api/dcim/devices/17/?format=json",
            "display": "dmi01-buffalo-sw01",
            "name": "dmi01-buffalo-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/sites/5/?format=json",
                "display": "DM-Buffalo",
                "name": "DM-Buffalo",
                "slug": "dm-buffalo",
            },
            "location": None,
            "rack": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/racks/4/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:11.883000Z",
        },
        {
            "id": 5,
            "url": "http://localhost:55891/api/dcim/devices/5/?format=json",
            "display": "dmi01-camden-rtr01",
            "name": "dmi01-camden-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/sites/6/?format=json",
                "display": "DM-Camden",
                "name": "DM-Camden",
                "slug": "dm-camden",
            },
            "location": None,
            "rack": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/racks/5/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 185,
                "url": "http://localhost:55891/api/ipam/ip-addresses/185/?format=json",
                "display": "5.5.5.5/10",
                "family": 4,
                "address": "5.5.5.5/10",
            },
            "primary_ip4": {
                "id": 185,
                "url": "http://localhost:55891/api/ipam/ip-addresses/185/?format=json",
                "display": "5.5.5.5/10",
                "family": 4,
                "address": "5.5.5.5/10",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:27:37.376000Z",
        },
        {
            "id": 18,
            "url": "http://localhost:55891/api/dcim/devices/18/?format=json",
            "display": "dmi01-camden-sw01",
            "name": "dmi01-camden-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/sites/6/?format=json",
                "display": "DM-Camden",
                "name": "DM-Camden",
                "slug": "dm-camden",
            },
            "location": None,
            "rack": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/racks/5/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:11.968000Z",
        },
        {
            "id": 6,
            "url": "http://localhost:55891/api/dcim/devices/6/?format=json",
            "display": "dmi01-nashua-rtr01",
            "name": "dmi01-nashua-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/sites/7/?format=json",
                "display": "DM-Nashua",
                "name": "DM-Nashua",
                "slug": "dm-nashua",
            },
            "location": None,
            "rack": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/racks/6/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 186,
                "url": "http://localhost:55891/api/ipam/ip-addresses/186/?format=json",
                "display": "6.6.6.6/10",
                "family": 4,
                "address": "6.6.6.6/10",
            },
            "primary_ip4": {
                "id": 186,
                "url": "http://localhost:55891/api/ipam/ip-addresses/186/?format=json",
                "display": "6.6.6.6/10",
                "family": 4,
                "address": "6.6.6.6/10",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:27:46.894000Z",
        },
        {
            "id": 19,
            "url": "http://localhost:55891/api/dcim/devices/19/?format=json",
            "display": "dmi01-nashua-sw01",
            "name": "dmi01-nashua-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/sites/7/?format=json",
                "display": "DM-Nashua",
                "name": "DM-Nashua",
                "slug": "dm-nashua",
            },
            "location": None,
            "rack": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/racks/6/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:12.071000Z",
        },
        {
            "id": 7,
            "url": "http://localhost:55891/api/dcim/devices/7/?format=json",
            "display": "dmi01-pittsfield-rtr01",
            "name": "dmi01-pittsfield-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 8,
                "url": "http://localhost:55891/api/dcim/sites/8/?format=json",
                "display": "DM-Pittsfield",
                "name": "DM-Pittsfield",
                "slug": "dm-pittsfield",
            },
            "location": None,
            "rack": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/racks/7/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 187,
                "url": "http://localhost:55891/api/ipam/ip-addresses/187/?format=json",
                "display": "7.7.7.7/10",
                "family": 4,
                "address": "7.7.7.7/10",
            },
            "primary_ip4": {
                "id": 187,
                "url": "http://localhost:55891/api/ipam/ip-addresses/187/?format=json",
                "display": "7.7.7.7/10",
                "family": 4,
                "address": "7.7.7.7/10",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:27:59.599000Z",
        },
        {
            "id": 20,
            "url": "http://localhost:55891/api/dcim/devices/20/?format=json",
            "display": "dmi01-pittsfield-sw01",
            "name": "dmi01-pittsfield-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 8,
                "url": "http://localhost:55891/api/dcim/sites/8/?format=json",
                "display": "DM-Pittsfield",
                "name": "DM-Pittsfield",
                "slug": "dm-pittsfield",
            },
            "location": None,
            "rack": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/racks/7/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:12.204000Z",
        },
        {
            "id": 8,
            "url": "http://localhost:55891/api/dcim/devices/8/?format=json",
            "display": "dmi01-rochester-rtr01",
            "name": "dmi01-rochester-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/sites/9/?format=json",
                "display": "DM-Rochester",
                "name": "DM-Rochester",
                "slug": "dm-rochester",
            },
            "location": None,
            "rack": {
                "id": 8,
                "url": "http://localhost:55891/api/dcim/racks/8/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 188,
                "url": "http://localhost:55891/api/ipam/ip-addresses/188/?format=json",
                "display": "8.8.8.8/32",
                "family": 4,
                "address": "8.8.8.8/32",
            },
            "primary_ip4": {
                "id": 188,
                "url": "http://localhost:55891/api/ipam/ip-addresses/188/?format=json",
                "display": "8.8.8.8/32",
                "family": 4,
                "address": "8.8.8.8/32",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:28:11.364000Z",
        },
        {
            "id": 21,
            "url": "http://localhost:55891/api/dcim/devices/21/?format=json",
            "display": "dmi01-rochster-sw01",
            "name": "dmi01-rochster-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/sites/9/?format=json",
                "display": "DM-Rochester",
                "name": "DM-Rochester",
                "slug": "dm-rochester",
            },
            "location": None,
            "rack": {
                "id": 8,
                "url": "http://localhost:55891/api/dcim/racks/8/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:12.287000Z",
        },
        {
            "id": 9,
            "url": "http://localhost:55891/api/dcim/devices/9/?format=json",
            "display": "dmi01-scranton-rtr01",
            "name": "dmi01-scranton-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 10,
                "url": "http://localhost:55891/api/dcim/sites/10/?format=json",
                "display": "DM-Scranton",
                "name": "DM-Scranton",
                "slug": "dm-scranton",
            },
            "location": None,
            "rack": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/racks/9/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 189,
                "url": "http://localhost:55891/api/ipam/ip-addresses/189/?format=json",
                "display": "9.9.9.9/32",
                "family": 4,
                "address": "9.9.9.9/32",
            },
            "primary_ip4": {
                "id": 189,
                "url": "http://localhost:55891/api/ipam/ip-addresses/189/?format=json",
                "display": "9.9.9.9/32",
                "family": 4,
                "address": "9.9.9.9/32",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:28:23.927000Z",
        },
        {
            "id": 22,
            "url": "http://localhost:55891/api/dcim/devices/22/?format=json",
            "display": "dmi01-scranton-sw01",
            "name": "dmi01-scranton-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 10,
                "url": "http://localhost:55891/api/dcim/sites/10/?format=json",
                "display": "DM-Scranton",
                "name": "DM-Scranton",
                "slug": "dm-scranton",
            },
            "location": None,
            "rack": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/racks/9/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:12.370000Z",
        },
        {
            "id": 10,
            "url": "http://localhost:55891/api/dcim/devices/10/?format=json",
            "display": "dmi01-stamford-rtr01",
            "name": "dmi01-stamford-rtr01",
            "device_type": {
                "id": 6,
                "url": "http://localhost:55891/api/dcim/device-types/6/?format=json",
                "display": "ISR 1111-8P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "ISR 1111-8P",
                "slug": "isr1111",
            },
            "device_role": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/device-roles/1/?format=json",
                "display": "Router",
                "name": "Router",
                "slug": "router",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/platforms/1/?format=json",
                "display": "ios",
                "name": "ios",
                "slug": "ios",
            },
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 11,
                "url": "http://localhost:55891/api/dcim/sites/11/?format=json",
                "display": "DM-Stamford",
                "name": "DM-Stamford",
                "slug": "dm-stamford",
            },
            "location": None,
            "rack": {
                "id": 10,
                "url": "http://localhost:55891/api/dcim/racks/10/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 4,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": {
                "id": 190,
                "url": "http://localhost:55891/api/ipam/ip-addresses/190/?format=json",
                "display": "10.10.10.10/10",
                "family": 4,
                "address": "10.10.10.10/10",
            },
            "primary_ip4": {
                "id": 190,
                "url": "http://localhost:55891/api/ipam/ip-addresses/190/?format=json",
                "display": "10.10.10.10/10",
                "family": 4,
                "address": "10.10.10.10/10",
            },
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-20T00:00:00Z",
            "last_updated": "2022-06-15T07:28:37.781000Z",
        },
        {
            "id": 23,
            "url": "http://localhost:55891/api/dcim/devices/23/?format=json",
            "display": "dmi01-stamford-sw01",
            "name": "dmi01-stamford-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 11,
                "url": "http://localhost:55891/api/dcim/sites/11/?format=json",
                "display": "DM-Stamford",
                "name": "DM-Stamford",
                "slug": "dm-stamford",
            },
            "location": None,
            "rack": {
                "id": 10,
                "url": "http://localhost:55891/api/dcim/racks/10/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:12.454000Z",
        },
        {
            "id": 24,
            "url": "http://localhost:55891/api/dcim/devices/24/?format=json",
            "display": "dmi01-syracuse-sw01",
            "name": "dmi01-syracuse-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 12,
                "url": "http://localhost:55891/api/dcim/sites/12/?format=json",
                "display": "DM-Syracuse",
                "name": "DM-Syracuse",
                "slug": "dm-syracuse",
            },
            "location": None,
            "rack": {
                "id": 11,
                "url": "http://localhost:55891/api/dcim/racks/11/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:12.540000Z",
        },
        {
            "id": 25,
            "url": "http://localhost:55891/api/dcim/devices/25/?format=json",
            "display": "dmi01-utica-sw01",
            "name": "dmi01-utica-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 13,
                "url": "http://localhost:55891/api/dcim/sites/13/?format=json",
                "display": "DM-Utica",
                "name": "DM-Utica",
                "slug": "dm-utica",
            },
            "location": None,
            "rack": {
                "id": 12,
                "url": "http://localhost:55891/api/dcim/racks/12/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:12.622000Z",
        },
        {
            "id": 26,
            "url": "http://localhost:55891/api/dcim/devices/26/?format=json",
            "display": "dmi01-yonkers-sw01",
            "name": "dmi01-yonkers-sw01",
            "device_type": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-types/7/?format=json",
                "display": "C9200-48P",
                "manufacturer": {
                    "id": 3,
                    "url": "http://localhost:55891/api/dcim/manufacturers/3/?format=json",
                    "display": "Cisco",
                    "name": "Cisco",
                    "slug": "cisco",
                },
                "model": "C9200-48P",
                "slug": "c9200-48p",
            },
            "device_role": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/device-roles/4/?format=json",
                "display": "Access Switch",
                "name": "Access Switch",
                "slug": "access-switch",
            },
            "tenant": {
                "id": 5,
                "url": "http://localhost:55891/api/tenancy/tenants/5/?format=json",
                "display": "Dunder-Mifflin, Inc.",
                "name": "Dunder-Mifflin, Inc.",
                "slug": "dunder-mifflin",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 14,
                "url": "http://localhost:55891/api/dcim/sites/14/?format=json",
                "display": "DM-Yonkers",
                "name": "DM-Yonkers",
                "slug": "dm-yonkers",
            },
            "location": None,
            "rack": {
                "id": 13,
                "url": "http://localhost:55891/api/dcim/racks/13/?format=json",
                "display": "Comms closet",
                "name": "Comms closet",
            },
            "position": 10,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2020-12-22T00:00:00Z",
            "last_updated": "2020-12-22T02:11:12.705000Z",
        },
        {
            "id": 96,
            "url": "http://localhost:55891/api/dcim/devices/96/?format=json",
            "display": "ncsu-coreswitch1",
            "name": "ncsu-coreswitch1",
            "device_type": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/device-types/3/?format=json",
                "display": "EX9214",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "EX9214",
                "slug": "ex9214",
            },
            "device_role": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/device-roles/2/?format=json",
                "display": "Core Switch",
                "name": "Core Switch",
                "slug": "core-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 16,
                "url": "http://localhost:55891/api/dcim/racks/16/?format=json",
                "display": "R103",
                "name": "R103",
            },
            "position": 6,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-04-02T00:00:00Z",
            "last_updated": "2021-04-02T17:31:41.398000Z",
        },
        {
            "id": 97,
            "url": "http://localhost:55891/api/dcim/devices/97/?format=json",
            "display": "ncsu-coreswitch2",
            "name": "ncsu-coreswitch2",
            "device_type": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/device-types/3/?format=json",
                "display": "EX9214",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "EX9214",
                "slug": "ex9214",
            },
            "device_role": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/device-roles/2/?format=json",
                "display": "Core Switch",
                "name": "Core Switch",
                "slug": "core-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 17,
                "url": "http://localhost:55891/api/dcim/racks/17/?format=json",
                "display": "R104",
                "name": "R104",
            },
            "position": 6,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-04-02T00:00:00Z",
            "last_updated": "2021-04-02T17:31:56.519000Z",
        },
        {
            "id": 94,
            "url": "http://localhost:55891/api/dcim/devices/94/?format=json",
            "display": "ncsu117-distswitch1",
            "name": "ncsu117-distswitch1",
            "device_type": {
                "id": 12,
                "url": "http://localhost:55891/api/dcim/device-types/12/?format=json",
                "display": "QFX5110-48S-4C",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5110-48S-4C",
                "slug": "qfx5110-48s-4c",
            },
            "device_role": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/device-roles/3/?format=json",
                "display": "Distribution Switch",
                "name": "Distribution Switch",
                "slug": "distribution-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 22,
                "url": "http://localhost:55891/api/dcim/sites/22/?format=json",
                "display": "D. S. Weaver Labs",
                "name": "D. S. Weaver Labs",
                "slug": "ncsu-117",
            },
            "location": None,
            "rack": {
                "id": 40,
                "url": "http://localhost:55891/api/dcim/racks/40/?format=json",
                "display": "IDF117",
                "name": "IDF117",
            },
            "position": 36,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-04-02T00:00:00Z",
            "last_updated": "2021-04-02T17:29:22.719000Z",
        },
        {
            "id": 95,
            "url": "http://localhost:55891/api/dcim/devices/95/?format=json",
            "display": "ncsu118-distswitch1",
            "name": "ncsu118-distswitch1",
            "device_type": {
                "id": 12,
                "url": "http://localhost:55891/api/dcim/device-types/12/?format=json",
                "display": "QFX5110-48S-4C",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5110-48S-4C",
                "slug": "qfx5110-48s-4c",
            },
            "device_role": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/device-roles/3/?format=json",
                "display": "Distribution Switch",
                "name": "Distribution Switch",
                "slug": "distribution-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 23,
                "url": "http://localhost:55891/api/dcim/sites/23/?format=json",
                "display": "Grinnells Lab",
                "name": "Grinnells Lab",
                "slug": "ncsu-118",
            },
            "location": None,
            "rack": {
                "id": 38,
                "url": "http://localhost:55891/api/dcim/racks/38/?format=json",
                "display": "IDF118",
                "name": "IDF118",
            },
            "position": 36,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-04-02T00:00:00Z",
            "last_updated": "2021-04-02T17:29:56.066000Z",
        },
        {
            "id": 93,
            "url": "http://localhost:55891/api/dcim/devices/93/?format=json",
            "display": "ncsu128-distswitch1",
            "name": "ncsu128-distswitch1",
            "device_type": {
                "id": 12,
                "url": "http://localhost:55891/api/dcim/device-types/12/?format=json",
                "display": "QFX5110-48S-4C",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5110-48S-4C",
                "slug": "qfx5110-48s-4c",
            },
            "device_role": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/device-roles/3/?format=json",
                "display": "Distribution Switch",
                "name": "Distribution Switch",
                "slug": "distribution-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 24,
                "url": "http://localhost:55891/api/dcim/sites/24/?format=json",
                "display": "Butler Communications",
                "name": "Butler Communications",
                "slug": "ncsu-128",
            },
            "location": None,
            "rack": {
                "id": 39,
                "url": "http://localhost:55891/api/dcim/racks/39/?format=json",
                "display": "IDF128",
                "name": "IDF128",
            },
            "position": 32,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-04-02T00:00:00Z",
            "last_updated": "2021-04-02T17:28:42.498000Z",
        },
        {
            "id": 98,
            "url": "http://localhost:55891/api/dcim/devices/98/?format=json",
            "display": "r105-torsw:1 (98)",
            "name": None,
            "device_type": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/device-types/5/?format=json",
                "display": "QFX5100-48T-6Q",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5100-48T-6Q",
                "slug": "qfx5100-48t-6q",
            },
            "device_role": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/device-roles/9/?format=json",
                "display": "ToR Switch",
                "name": "ToR Switch",
                "slug": "tor-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 18,
                "url": "http://localhost:55891/api/dcim/racks/18/?format=json",
                "display": "R105",
                "name": "R105",
            },
            "position": 26,
            "face": {"value": "rear", "label": "Rear"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/virtual-chassis/1/?format=json",
                "display": "r105-torsw",
                "name": "r105-torsw",
                "master": {
                    "id": 98,
                    "url": "http://localhost:55891/api/dcim/devices/98/?format=json",
                    "display": "r105-torsw:1 (98)",
                    "name": None,
                },
            },
            "vc_position": 1,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-12-30T00:00:00Z",
            "last_updated": "2022-06-15T07:23:33.841000Z",
        },
        {
            "id": 99,
            "url": "http://localhost:55891/api/dcim/devices/99/?format=json",
            "display": "r105-torsw:2 (99)",
            "name": None,
            "device_type": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/device-types/5/?format=json",
                "display": "QFX5100-48T-6Q",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5100-48T-6Q",
                "slug": "qfx5100-48t-6q",
            },
            "device_role": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/device-roles/9/?format=json",
                "display": "ToR Switch",
                "name": "ToR Switch",
                "slug": "tor-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 18,
                "url": "http://localhost:55891/api/dcim/racks/18/?format=json",
                "display": "R105",
                "name": "R105",
            },
            "position": 25,
            "face": {"value": "rear", "label": "Rear"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/virtual-chassis/1/?format=json",
                "display": "r105-torsw",
                "name": "r105-torsw",
                "master": {
                    "id": 98,
                    "url": "http://localhost:55891/api/dcim/devices/98/?format=json",
                    "display": "r105-torsw:1 (98)",
                    "name": None,
                },
            },
            "vc_position": 2,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-12-30T00:00:00Z",
            "last_updated": "2021-12-30T16:16:55.811000Z",
        },
        {
            "id": 100,
            "url": "http://localhost:55891/api/dcim/devices/100/?format=json",
            "display": "r106-torsw:1 (100)",
            "name": None,
            "device_type": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/device-types/5/?format=json",
                "display": "QFX5100-48T-6Q",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5100-48T-6Q",
                "slug": "qfx5100-48t-6q",
            },
            "device_role": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/device-roles/9/?format=json",
                "display": "ToR Switch",
                "name": "ToR Switch",
                "slug": "tor-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 19,
                "url": "http://localhost:55891/api/dcim/racks/19/?format=json",
                "display": "R106",
                "name": "R106",
            },
            "position": 26,
            "face": {"value": "rear", "label": "Rear"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/virtual-chassis/2/?format=json",
                "display": "r106-torsw",
                "name": "r106-torsw",
                "master": {
                    "id": 100,
                    "url": "http://localhost:55891/api/dcim/devices/100/?format=json",
                    "display": "r106-torsw:1 (100)",
                    "name": None,
                },
            },
            "vc_position": 1,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-12-30T00:00:00Z",
            "last_updated": "2022-06-15T07:23:33.855000Z",
        },
        {
            "id": 101,
            "url": "http://localhost:55891/api/dcim/devices/101/?format=json",
            "display": "r106-torsw:2 (101)",
            "name": None,
            "device_type": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/device-types/5/?format=json",
                "display": "QFX5100-48T-6Q",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5100-48T-6Q",
                "slug": "qfx5100-48t-6q",
            },
            "device_role": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/device-roles/9/?format=json",
                "display": "ToR Switch",
                "name": "ToR Switch",
                "slug": "tor-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 19,
                "url": "http://localhost:55891/api/dcim/racks/19/?format=json",
                "display": "R106",
                "name": "R106",
            },
            "position": 25,
            "face": {"value": "rear", "label": "Rear"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/virtual-chassis/2/?format=json",
                "display": "r106-torsw",
                "name": "r106-torsw",
                "master": {
                    "id": 100,
                    "url": "http://localhost:55891/api/dcim/devices/100/?format=json",
                    "display": "r106-torsw:1 (100)",
                    "name": None,
                },
            },
            "vc_position": 2,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-12-30T00:00:00Z",
            "last_updated": "2021-12-30T16:17:27.958000Z",
        },
        {
            "id": 102,
            "url": "http://localhost:55891/api/dcim/devices/102/?format=json",
            "display": "r107-torsw:1 (102)",
            "name": None,
            "device_type": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/device-types/5/?format=json",
                "display": "QFX5100-48T-6Q",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5100-48T-6Q",
                "slug": "qfx5100-48t-6q",
            },
            "device_role": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/device-roles/9/?format=json",
                "display": "ToR Switch",
                "name": "ToR Switch",
                "slug": "tor-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 20,
                "url": "http://localhost:55891/api/dcim/racks/20/?format=json",
                "display": "R107",
                "name": "R107",
            },
            "position": 26,
            "face": {"value": "rear", "label": "Rear"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/virtual-chassis/3/?format=json",
                "display": "r107-torsw",
                "name": "r107-torsw",
                "master": {
                    "id": 102,
                    "url": "http://localhost:55891/api/dcim/devices/102/?format=json",
                    "display": "r107-torsw:1 (102)",
                    "name": None,
                },
            },
            "vc_position": 1,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-12-30T00:00:00Z",
            "last_updated": "2022-06-15T07:23:33.866000Z",
        },
        {
            "id": 103,
            "url": "http://localhost:55891/api/dcim/devices/103/?format=json",
            "display": "r107-torsw:2 (103)",
            "name": None,
            "device_type": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/device-types/5/?format=json",
                "display": "QFX5100-48T-6Q",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5100-48T-6Q",
                "slug": "qfx5100-48t-6q",
            },
            "device_role": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/device-roles/9/?format=json",
                "display": "ToR Switch",
                "name": "ToR Switch",
                "slug": "tor-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 20,
                "url": "http://localhost:55891/api/dcim/racks/20/?format=json",
                "display": "R107",
                "name": "R107",
            },
            "position": 25,
            "face": {"value": "rear", "label": "Rear"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": {
                "id": 3,
                "url": "http://localhost:55891/api/dcim/virtual-chassis/3/?format=json",
                "display": "r107-torsw",
                "name": "r107-torsw",
                "master": {
                    "id": 102,
                    "url": "http://localhost:55891/api/dcim/devices/102/?format=json",
                    "display": "r107-torsw:1 (102)",
                    "name": None,
                },
            },
            "vc_position": 2,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-12-30T00:00:00Z",
            "last_updated": "2021-12-30T16:17:56.487000Z",
        },
        {
            "id": 104,
            "url": "http://localhost:55891/api/dcim/devices/104/?format=json",
            "display": "r108-torsw:1 (104)",
            "name": None,
            "device_type": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/device-types/5/?format=json",
                "display": "QFX5100-48T-6Q",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5100-48T-6Q",
                "slug": "qfx5100-48t-6q",
            },
            "device_role": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/device-roles/9/?format=json",
                "display": "ToR Switch",
                "name": "ToR Switch",
                "slug": "tor-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/racks/21/?format=json",
                "display": "R108",
                "name": "R108",
            },
            "position": 26,
            "face": {"value": "rear", "label": "Rear"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/virtual-chassis/4/?format=json",
                "display": "r108-torsw",
                "name": "r108-torsw",
                "master": {
                    "id": 104,
                    "url": "http://localhost:55891/api/dcim/devices/104/?format=json",
                    "display": "r108-torsw:1 (104)",
                    "name": None,
                },
            },
            "vc_position": 1,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-12-30T00:00:00Z",
            "last_updated": "2022-06-15T07:23:33.882000Z",
        },
        {
            "id": 105,
            "url": "http://localhost:55891/api/dcim/devices/105/?format=json",
            "display": "r108-torsw:2 (105)",
            "name": None,
            "device_type": {
                "id": 5,
                "url": "http://localhost:55891/api/dcim/device-types/5/?format=json",
                "display": "QFX5100-48T-6Q",
                "manufacturer": {
                    "id": 7,
                    "url": "http://localhost:55891/api/dcim/manufacturers/7/?format=json",
                    "display": "Juniper",
                    "name": "Juniper",
                    "slug": "juniper",
                },
                "model": "QFX5100-48T-6Q",
                "slug": "qfx5100-48t-6q",
            },
            "device_role": {
                "id": 9,
                "url": "http://localhost:55891/api/dcim/device-roles/9/?format=json",
                "display": "ToR Switch",
                "name": "ToR Switch",
                "slug": "tor-switch",
            },
            "tenant": {
                "id": 13,
                "url": "http://localhost:55891/api/tenancy/tenants/13/?format=json",
                "display": "NC State University",
                "name": "NC State University",
                "slug": "nc-state",
            },
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 1,
                "url": "http://localhost:55891/api/dcim/locations/1/?format=json",
                "display": "Row 1",
                "name": "Row 1",
                "slug": "row-1",
                "_depth": 0,
            },
            "rack": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/racks/21/?format=json",
                "display": "R108",
                "name": "R108",
            },
            "position": 25,
            "face": {"value": "rear", "label": "Rear"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": {
                "id": 4,
                "url": "http://localhost:55891/api/dcim/virtual-chassis/4/?format=json",
                "display": "r108-torsw",
                "name": "r108-torsw",
                "master": {
                    "id": 104,
                    "url": "http://localhost:55891/api/dcim/devices/104/?format=json",
                    "display": "r108-torsw:1 (104)",
                    "name": None,
                },
            },
            "vc_position": 2,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2021-12-30T00:00:00Z",
            "last_updated": "2021-12-30T16:18:24.555000Z",
        },
        {
            "id": 106,
            "url": "http://localhost:55891/api/dcim/devices/106/?format=json",
            "display": "Lenovo Flex system (106)",
            "name": None,
            "device_type": {
                "id": 14,
                "url": "http://localhost:55891/api/dcim/device-types/14/?format=json",
                "display": "Flex system",
                "manufacturer": {
                    "id": 14,
                    "url": "http://localhost:55891/api/dcim/manufacturers/14/?format=json",
                    "display": "Lenovo",
                    "name": "Lenovo",
                    "slug": "lenovo",
                },
                "model": "Flex system",
                "slug": "flex-system",
            },
            "device_role": {
                "id": 7,
                "url": "http://localhost:55891/api/dcim/device-roles/7/?format=json",
                "display": "Application Server",
                "name": "Application Server",
                "slug": "application-server",
            },
            "tenant": None,
            "platform": None,
            "serial": "",
            "asset_tag": None,
            "site": {
                "id": 21,
                "url": "http://localhost:55891/api/dcim/sites/21/?format=json",
                "display": "MDF",
                "name": "MDF",
                "slug": "ncsu-065",
            },
            "location": {
                "id": 2,
                "url": "http://localhost:55891/api/dcim/locations/2/?format=json",
                "display": "Row 2",
                "name": "Row 2",
                "slug": "row-2",
                "_depth": 0,
            },
            "rack": {
                "id": 22,
                "url": "http://localhost:55891/api/dcim/racks/22/?format=json",
                "display": "R201",
                "name": "R201",
            },
            "position": 9,
            "face": {"value": "front", "label": "Front"},
            "parent_device": None,
            "status": {"value": "active", "label": "Active"},
            "airflow": None,
            "primary_ip": None,
            "primary_ip4": None,
            "primary_ip6": None,
            "cluster": None,
            "virtual_chassis": None,
            "vc_position": None,
            "vc_priority": None,
            "comments": "",
            "local_context_data": None,
            "tags": [],
            "custom_fields": {},
            "config_context": {},
            "created": "2022-01-10T00:00:00Z",
            "last_updated": "2022-01-10T21:00:04.030000Z",
        },
    ],
}

NETBOX_VMS_API_CALL = "/api/virtualization/virtual-machines/?format=json"
NETBOX_VMS_API_RESPONSE = {"count": 0,
                           "next": None, "previous": None, "results": []}

NETBOX_GENERATED_TESTBED = {
    "testbed": {"credentials": {"default": {"username": "test", "password": "test"}}},
    "devices": {
        "dmi01-albany-rtr01": {
            "os": "ios",
            "alias": "dmi01-albany-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "2.2.2.2"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
        "dmi01-binghamton-rtr01": {
            "os": "ios",
            "alias": "dmi01-binghamton-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "3.3.3.3"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
        "dmi01-buffalo-rtr01": {
            "os": "ios",
            "alias": "dmi01-buffalo-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "4.4.4.4"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
        "dmi01-camden-rtr01": {
            "os": "ios",
            "alias": "dmi01-camden-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "5.5.5.5"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
        "dmi01-nashua-rtr01": {
            "os": "ios",
            "alias": "dmi01-nashua-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "6.6.6.6"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
        "dmi01-pittsfield-rtr01": {
            "os": "ios",
            "alias": "dmi01-pittsfield-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "7.7.7.7"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
        "dmi01-rochester-rtr01": {
            "os": "ios",
            "alias": "dmi01-rochester-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "8.8.8.8"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
        "dmi01-scranton-rtr01": {
            "os": "ios",
            "alias": "dmi01-scranton-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "9.9.9.9"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
        "dmi01-stamford-rtr01": {
            "os": "ios",
            "alias": "dmi01-stamford-rtr01",
            "platform": "ios",
            "type": "ISR 1111-8P",
            "connections": {"cli": {"protocol": "ssh", "ip": "10.10.10.10"}},
            "credentials": {"default": {"username": "test", "password": "test"}},
        },
    },
    "topology": {},
}
