'''
Module:
    pyats.contrib

Description:
    The `pyats.contrib` package is a collection of open-source extensions for
    the pyATS framework.

    Plugins, extensions and codes under this project are designed to
    automatically integrate into the pyATS framework using its various
    published hook/entry-point interfaces.
'''

__version__ = '25.1'
__author__ = 'Cisco Systems Inc.'
__contact__ = ['pyats-support@cisco.com', 'pyats-support-ext@cisco.com']
__copyright__ = 'Copyright (c) 2020, Cisco Systems Inc.'

